@@ -42,7 +42,7 @@
 "                    Susan Shortreed, University of Washington\n",
 "                    Jeremy Tantrum, University of Washington\n",
 "                    Peter Hoff, University of Washington\n",sep=""))
-    cat('See http://www.csde.washington.edu/statnet\n')
+    cat('See http://www.csde.washington.edu/statnet/latentnet\n')
     cat('Type help(package="latentnet") to get started.\n')
     cat('To cite, see citation("latentnet")\n')
     require(network, quietly=TRUE)
